# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Legal Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.legal.models import AcceptAgreementRequest
from ..api.legal.models import AcceptAgreementResponse
from ..api.legal.models import CreateBasePolicyRequest
from ..api.legal.models import CreateBasePolicyRequestV2
from ..api.legal.models import CreateBasePolicyResponse
from ..api.legal.models import CreateLocalizedPolicyVersionRequest
from ..api.legal.models import CreateLocalizedPolicyVersionResponse
from ..api.legal.models import CreatePolicyVersionRequest
from ..api.legal.models import CreatePolicyVersionResponse
from ..api.legal.models import DownloadExportedAgreementsInCSVResponse
from ..api.legal.models import ErrorEntity
from ..api.legal.models import FieldValidationError
from ..api.legal.models import InitiateExportAgreementsToCSVResponse
from ..api.legal.models import LegalReadinessStatusResponse
from ..api.legal.models import LocalizedPolicyVersionObject
from ..api.legal.models import PagedRetrieveUserAcceptedAgreementResponse
from ..api.legal.models import Paging
from ..api.legal.models import Permission
from ..api.legal.models import PolicyObject
from ..api.legal.models import PolicyVersionObject
from ..api.legal.models import PolicyVersionWithLocalizedVersionObject
from ..api.legal.models import RetrieveAcceptedAgreementResponse
from ..api.legal.models import RetrieveBasePolicyResponse
from ..api.legal.models import RetrieveLocalizedPolicyVersionPublicResponse
from ..api.legal.models import RetrieveLocalizedPolicyVersionResponse
from ..api.legal.models import RetrievePolicyPublicResponse
from ..api.legal.models import RetrievePolicyResponse
from ..api.legal.models import RetrievePolicyTypeResponse
from ..api.legal.models import RetrievePolicyVersionResponse
from ..api.legal.models import RetrieveUserAcceptedAgreementResponse
from ..api.legal.models import RetrieveUserEligibilitiesIndirectResponse
from ..api.legal.models import RetrieveUserEligibilitiesResponse
from ..api.legal.models import RetrieveUserInfoCacheStatusResponse
from ..api.legal.models import UpdateBasePolicyRequest
from ..api.legal.models import UpdateBasePolicyRequestV2
from ..api.legal.models import UpdateBasePolicyResponse
from ..api.legal.models import UpdateLocalizedPolicyVersionRequest
from ..api.legal.models import UpdateLocalizedPolicyVersionResponse
from ..api.legal.models import UpdatePolicyRequest
from ..api.legal.models import UpdatePolicyVersionRequest
from ..api.legal.models import UpdatePolicyVersionResponse
from ..api.legal.models import UploadLocalizedPolicyVersionAttachmentResponse
from ..api.legal.models import UploadPolicyVersionAttachmentRequest
from ..api.legal.models import UserAgreementsResponse
from ..api.legal.models import UsersAgreementsRequest
from ..api.legal.models import ValidationErrorEntity


def create_accept_agreement_request_example() -> AcceptAgreementRequest:
    instance = AcceptAgreementRequest()
    instance.is_accepted = randomize("bool")
    instance.localized_policy_version_id = randomize()
    instance.policy_id = randomize()
    instance.policy_version_id = randomize()
    instance.is_need_to_send_event_marketing = randomize("bool")
    return instance


def create_accept_agreement_response_example() -> AcceptAgreementResponse:
    instance = AcceptAgreementResponse()
    instance.comply = randomize("bool")
    instance.proceed = randomize("bool")
    return instance


def create_create_base_policy_request_example() -> CreateBasePolicyRequest:
    instance = CreateBasePolicyRequest()
    instance.affected_client_ids = [randomize()]
    instance.affected_countries = [randomize()]
    instance.base_policy_name = randomize()
    instance.description = randomize()
    instance.is_hidden = randomize("bool")
    instance.namespace = randomize("slug")
    instance.tags = [randomize()]
    instance.type_id = randomize()
    return instance


def create_create_base_policy_request_v2_example() -> CreateBasePolicyRequestV2:
    instance = CreateBasePolicyRequestV2()
    instance.affected_client_ids = [randomize()]
    instance.affected_countries = [randomize()]
    instance.base_policy_name = randomize()
    instance.description = randomize()
    instance.is_hidden = randomize("bool")
    instance.tags = [randomize()]
    instance.type_id = randomize()
    return instance


def create_create_base_policy_response_example() -> CreateBasePolicyResponse:
    instance = CreateBasePolicyResponse()
    instance.id_ = randomize()
    instance.affected_client_ids = [randomize()]
    instance.affected_countries = [randomize()]
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.global_policy_name = randomize()
    instance.is_hidden = randomize("bool")
    instance.namespace = randomize("slug")
    instance.policy_id = randomize()
    instance.tags = [randomize()]
    instance.type_id = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_create_localized_policy_version_request_example() -> (
    CreateLocalizedPolicyVersionRequest
):
    instance = CreateLocalizedPolicyVersionRequest()
    instance.content_type = randomize()
    instance.description = randomize()
    instance.locale_code = randomize()
    return instance


def create_create_localized_policy_version_response_example() -> (
    CreateLocalizedPolicyVersionResponse
):
    instance = CreateLocalizedPolicyVersionResponse()
    instance.id_ = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.locale_code = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_create_policy_version_request_example() -> CreatePolicyVersionRequest:
    instance = CreatePolicyVersionRequest()
    instance.description = randomize()
    instance.display_version = randomize()
    instance.is_committed = randomize("bool")
    return instance


def create_create_policy_version_response_example() -> CreatePolicyVersionResponse:
    instance = CreatePolicyVersionResponse()
    instance.id_ = randomize()
    instance.base_policy_id = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.display_version = randomize()
    instance.is_committed = randomize("bool")
    instance.updated_at = randomize("date")
    return instance


def create_download_exported_agreements_in_csv_response_example() -> (
    DownloadExportedAgreementsInCSVResponse
):
    instance = DownloadExportedAgreementsInCSVResponse()
    instance.done = randomize("bool")
    instance.download_url = randomize("url")
    return instance


def create_error_entity_example() -> ErrorEntity:
    instance = ErrorEntity()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    instance.dev_stack_trace = randomize()
    instance.message_variables = {randomize(): randomize()}
    instance.required_permission = create_permission_example()
    return instance


def create_field_validation_error_example() -> FieldValidationError:
    instance = FieldValidationError()
    instance.error_code = randomize()
    instance.error_field = randomize()
    instance.error_message = randomize()
    instance.error_value = randomize()
    instance.message_variables = {randomize(): randomize()}
    return instance


def create_initiate_export_agreements_to_csv_response_example() -> (
    InitiateExportAgreementsToCSVResponse
):
    instance = InitiateExportAgreementsToCSVResponse()
    instance.export_id = randomize()
    instance.processing = randomize("bool")
    return instance


def create_legal_readiness_status_response_example() -> LegalReadinessStatusResponse:
    instance = LegalReadinessStatusResponse()
    instance.is_ready = randomize("bool")
    return instance


def create_localized_policy_version_object_example() -> LocalizedPolicyVersionObject:
    instance = LocalizedPolicyVersionObject()
    instance.id_ = randomize()
    instance.is_default_selection = randomize("bool")
    instance.locale_code = randomize()
    instance.attachment_checksum = randomize()
    instance.attachment_location = randomize()
    instance.attachment_version_identifier = randomize()
    instance.content_type = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.published_date = randomize("date")
    instance.status = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_paged_retrieve_user_accepted_agreement_response_example() -> (
    PagedRetrieveUserAcceptedAgreementResponse
):
    instance = PagedRetrieveUserAcceptedAgreementResponse()
    instance.data = [create_retrieve_user_accepted_agreement_response_example()]
    instance.paging = create_paging_example()
    return instance


def create_paging_example() -> Paging:
    instance = Paging()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_permission_example() -> Permission:
    instance = Permission()
    instance.action = randomize("int", min_val=1, max_val=1000)
    instance.resource = randomize()
    return instance


def create_policy_object_example() -> PolicyObject:
    instance = PolicyObject()
    instance.country_code = randomize()
    instance.id_ = randomize()
    instance.is_default_opted = randomize("bool")
    instance.is_default_selection = randomize("bool")
    instance.is_mandatory = randomize("bool")
    instance.policy_name = randomize()
    instance.should_notify_on_update = randomize("bool")
    instance.country_group_code = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.readable_id = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_policy_version_object_example() -> PolicyVersionObject:
    instance = PolicyVersionObject()
    instance.display_version = randomize()
    instance.id_ = randomize()
    instance.is_committed = randomize("bool")
    instance.is_in_effect = randomize("bool")
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.published_date = randomize("date")
    instance.status = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_policy_version_with_localized_version_object_example() -> (
    PolicyVersionWithLocalizedVersionObject
):
    instance = PolicyVersionWithLocalizedVersionObject()
    instance.display_version = randomize()
    instance.id_ = randomize()
    instance.is_committed = randomize("bool")
    instance.is_in_effect = randomize("bool")
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.localized_policy_versions = [
        create_localized_policy_version_object_example()
    ]
    instance.published_date = randomize("date")
    instance.status = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_retrieve_accepted_agreement_response_example() -> (
    RetrieveAcceptedAgreementResponse
):
    instance = RetrieveAcceptedAgreementResponse()
    instance.id_ = randomize()
    instance.country_code = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.display_version = randomize()
    instance.is_accepted = randomize("bool")
    instance.localized_policy_version = create_localized_policy_version_object_example()
    instance.namespace = randomize("slug")
    instance.policy_id = randomize()
    instance.policy_name = randomize()
    instance.policy_type = randomize()
    instance.signing_date = randomize("date")
    instance.tags = [randomize()]
    instance.updated_at = randomize("date")
    instance.user_id = randomize("uid")
    return instance


def create_retrieve_base_policy_response_example() -> RetrieveBasePolicyResponse:
    instance = RetrieveBasePolicyResponse()
    instance.base_policy_name = randomize()
    instance.id_ = randomize()
    instance.namespace = randomize("slug")
    instance.affected_client_ids = [randomize()]
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.is_hidden = randomize("bool")
    instance.policies = [create_policy_object_example()]
    instance.policy_type_id = randomize()
    instance.policy_type_name = randomize()
    instance.tags = [randomize()]
    instance.updated_at = randomize("date")
    return instance


def create_retrieve_localized_policy_version_public_response_example() -> (
    RetrieveLocalizedPolicyVersionPublicResponse
):
    instance = RetrieveLocalizedPolicyVersionPublicResponse()
    instance.id_ = randomize()
    instance.locale_code = randomize()
    instance.namespace = randomize("slug")
    instance.policy = create_policy_object_example()
    instance.policy_version = create_policy_version_object_example()
    instance.attachment_checksum = randomize()
    instance.attachment_location = randomize()
    instance.attachment_version_identifier = randomize()
    instance.base_policy_id = randomize()
    instance.base_urls = [randomize()]
    instance.content_type = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.is_hidden = randomize("bool")
    instance.tags = [randomize()]
    instance.updated_at = randomize("date")
    return instance


def create_retrieve_localized_policy_version_response_example() -> (
    RetrieveLocalizedPolicyVersionResponse
):
    instance = RetrieveLocalizedPolicyVersionResponse()
    instance.id_ = randomize()
    instance.locale_code = randomize()
    instance.policy_version = create_policy_version_object_example()
    instance.attachment_checksum = randomize()
    instance.attachment_location = randomize()
    instance.attachment_version_identifier = randomize()
    instance.base_urls = [randomize()]
    instance.content_type = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.policy = create_policy_object_example()
    instance.updated_at = randomize("date")
    return instance


def create_retrieve_policy_public_response_example() -> RetrievePolicyPublicResponse:
    instance = RetrievePolicyPublicResponse()
    instance.base_policy_id = randomize()
    instance.country_code = randomize()
    instance.id_ = randomize()
    instance.is_default_opted = randomize("bool")
    instance.is_default_selection = randomize("bool")
    instance.is_mandatory = randomize("bool")
    instance.namespace = randomize("slug")
    instance.policy_name = randomize()
    instance.policy_type = randomize()
    instance.should_notify_on_update = randomize("bool")
    instance.base_urls = [randomize()]
    instance.country_group_code = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.policy_versions = [
        create_policy_version_with_localized_version_object_example()
    ]
    instance.readable_id = randomize()
    instance.tags = [randomize()]
    instance.updated_at = randomize("date")
    return instance


def create_retrieve_policy_response_example() -> RetrievePolicyResponse:
    instance = RetrievePolicyResponse()
    instance.country_code = randomize()
    instance.id_ = randomize()
    instance.is_default_opted = randomize("bool")
    instance.is_default_selection = randomize("bool")
    instance.is_mandatory = randomize("bool")
    instance.policy_name = randomize()
    instance.should_notify_on_update = randomize("bool")
    instance.country_group_code = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.policy_versions = [create_policy_version_object_example()]
    instance.readable_id = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_retrieve_policy_type_response_example() -> RetrievePolicyTypeResponse:
    instance = RetrievePolicyTypeResponse()
    instance.id_ = randomize()
    instance.is_need_document = randomize("bool")
    instance.policy_type_name = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_retrieve_policy_version_response_example() -> RetrievePolicyVersionResponse:
    instance = RetrievePolicyVersionResponse()
    instance.display_version = randomize()
    instance.id_ = randomize()
    instance.is_committed = randomize("bool")
    instance.is_in_effect = randomize("bool")
    instance.base_policy_id = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.localized_policy_versions = [
        create_localized_policy_version_object_example()
    ]
    instance.policy_id = randomize()
    instance.published_date = randomize("date")
    instance.status = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_retrieve_user_accepted_agreement_response_example() -> (
    RetrieveUserAcceptedAgreementResponse
):
    instance = RetrieveUserAcceptedAgreementResponse()
    instance.id_ = randomize()
    instance.created_at = randomize("date")
    instance.display_name = randomize("slug")
    instance.email = randomize("email")
    instance.is_accepted = randomize("bool")
    instance.localized_policy_version = create_localized_policy_version_object_example()
    instance.namespace = randomize("slug")
    instance.policy_name = randomize()
    instance.policy_type = randomize()
    instance.publisher_user_id = randomize()
    instance.signing_date = randomize("date")
    instance.updated_at = randomize("date")
    instance.user_id = randomize("uid")
    instance.username = randomize("slug")
    return instance


def create_retrieve_user_eligibilities_indirect_response_example() -> (
    RetrieveUserEligibilitiesIndirectResponse
):
    instance = RetrieveUserEligibilitiesIndirectResponse()
    instance.is_comply = randomize("bool")
    return instance


def create_retrieve_user_eligibilities_response_example() -> (
    RetrieveUserEligibilitiesResponse
):
    instance = RetrieveUserEligibilitiesResponse()
    instance.country_code = randomize()
    instance.is_accepted = randomize("bool")
    instance.is_mandatory = randomize("bool")
    instance.namespace = randomize("slug")
    instance.policy_id = randomize()
    instance.policy_name = randomize()
    instance.policy_type = randomize()
    instance.base_urls = [randomize()]
    instance.country_group_code = randomize()
    instance.description = randomize()
    instance.policy_versions = [
        create_policy_version_with_localized_version_object_example()
    ]
    instance.readable_id = randomize()
    return instance


def create_retrieve_user_info_cache_status_response_example() -> (
    RetrieveUserInfoCacheStatusResponse
):
    instance = RetrieveUserInfoCacheStatusResponse()
    instance.last_updated_at = randomize("date")
    instance.namespace = randomize("slug")
    return instance


def create_update_base_policy_request_example() -> UpdateBasePolicyRequest:
    instance = UpdateBasePolicyRequest()
    instance.affected_client_ids = [randomize()]
    instance.affected_countries = [randomize()]
    instance.base_policy_name = randomize()
    instance.description = randomize()
    instance.is_hidden = randomize("bool")
    instance.namespace = randomize("slug")
    instance.tags = [randomize()]
    return instance


def create_update_base_policy_request_v2_example() -> UpdateBasePolicyRequestV2:
    instance = UpdateBasePolicyRequestV2()
    instance.affected_client_ids = [randomize()]
    instance.affected_countries = [randomize()]
    instance.base_policy_name = randomize()
    instance.description = randomize()
    instance.is_hidden = randomize("bool")
    instance.tags = [randomize()]
    return instance


def create_update_base_policy_response_example() -> UpdateBasePolicyResponse:
    instance = UpdateBasePolicyResponse()
    instance.id_ = randomize()
    instance.affected_client_ids = [randomize()]
    instance.affected_countries = [randomize()]
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.global_policy_name = randomize()
    instance.is_hidden = randomize("bool")
    instance.namespace = randomize("slug")
    instance.policy_id = randomize()
    instance.tags = [randomize()]
    instance.type_id = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_update_localized_policy_version_request_example() -> (
    UpdateLocalizedPolicyVersionRequest
):
    instance = UpdateLocalizedPolicyVersionRequest()
    instance.attachment_checksum = randomize()
    instance.attachment_location = randomize()
    instance.attachment_version_identifier = randomize()
    instance.content_type = randomize()
    instance.description = randomize()
    return instance


def create_update_localized_policy_version_response_example() -> (
    UpdateLocalizedPolicyVersionResponse
):
    instance = UpdateLocalizedPolicyVersionResponse()
    instance.id_ = randomize()
    instance.attachment_checksum = randomize()
    instance.attachment_location = randomize()
    instance.attachment_version_identifier = randomize()
    instance.content_type = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.locale_code = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_update_policy_request_example() -> UpdatePolicyRequest:
    instance = UpdatePolicyRequest()
    instance.is_default_opted = randomize("bool")
    instance.is_mandatory = randomize("bool")
    instance.policy_name = randomize()
    instance.should_notify_on_update = randomize("bool")
    instance.description = randomize()
    instance.readable_id = randomize()
    return instance


def create_update_policy_version_request_example() -> UpdatePolicyVersionRequest:
    instance = UpdatePolicyVersionRequest()
    instance.description = randomize()
    instance.display_version = randomize()
    instance.is_committed = randomize("bool")
    return instance


def create_update_policy_version_response_example() -> UpdatePolicyVersionResponse:
    instance = UpdatePolicyVersionResponse()
    instance.id_ = randomize()
    instance.base_policy_id = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.display_version = randomize()
    instance.is_committed = randomize("bool")
    instance.published_date = randomize("date")
    instance.status = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_upload_localized_policy_version_attachment_response_example() -> (
    UploadLocalizedPolicyVersionAttachmentResponse
):
    instance = UploadLocalizedPolicyVersionAttachmentResponse()
    instance.attachment_checksum = randomize()
    instance.attachment_location = randomize()
    instance.attachment_upload_url = randomize("url")
    return instance


def create_upload_policy_version_attachment_request_example() -> (
    UploadPolicyVersionAttachmentRequest
):
    instance = UploadPolicyVersionAttachmentRequest()
    instance.content_md5 = randomize()
    instance.content_type = randomize()
    return instance


def create_user_agreements_response_example() -> UserAgreementsResponse:
    instance = UserAgreementsResponse()
    instance.agreements = [create_retrieve_accepted_agreement_response_example()]
    instance.user_id = randomize("uid")
    return instance


def create_users_agreements_request_example() -> UsersAgreementsRequest:
    instance = UsersAgreementsRequest()
    instance.user_ids = [randomize()]
    instance.current_published_only = randomize("bool")
    return instance


def create_validation_error_entity_example() -> ValidationErrorEntity:
    instance = ValidationErrorEntity()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    instance.errors = [create_field_validation_error_example()]
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Basic Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ConfigInfo(Model):
    """Config info (ConfigInfo)

    Properties:
        created_at: (createdAt) OPTIONAL str

        key: (key) OPTIONAL str

        namespace: (namespace) OPTIONAL str

        updated_at: (updatedAt) OPTIONAL str

        value: (value) OPTIONAL str
    """

    # region fields

    created_at: str  # OPTIONAL
    key: str  # OPTIONAL
    namespace: str  # OPTIONAL
    updated_at: str  # OPTIONAL
    value: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: str) -> ConfigInfo:
        self.created_at = value
        return self

    def with_key(self, value: str) -> ConfigInfo:
        self.key = value
        return self

    def with_namespace(self, value: str) -> ConfigInfo:
        self.namespace = value
        return self

    def with_updated_at(self, value: str) -> ConfigInfo:
        self.updated_at = value
        return self

    def with_value(self, value: str) -> ConfigInfo:
        self.value = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "key"):
            result["key"] = str(self.key)
        elif include_empty:
            result["key"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "updated_at"):
            result["updatedAt"] = str(self.updated_at)
        elif include_empty:
            result["updatedAt"] = ""
        if hasattr(self, "value"):
            result["value"] = str(self.value)
        elif include_empty:
            result["value"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: Optional[str] = None,
        key: Optional[str] = None,
        namespace: Optional[str] = None,
        updated_at: Optional[str] = None,
        value: Optional[str] = None,
        **kwargs,
    ) -> ConfigInfo:
        instance = cls()
        if created_at is not None:
            instance.created_at = created_at
        if key is not None:
            instance.key = key
        if namespace is not None:
            instance.namespace = namespace
        if updated_at is not None:
            instance.updated_at = updated_at
        if value is not None:
            instance.value = value
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> ConfigInfo:
        instance = cls()
        if not dict_:
            return instance
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "key" in dict_ and dict_["key"] is not None:
            instance.key = str(dict_["key"])
        elif include_empty:
            instance.key = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = str(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = ""
        if "value" in dict_ and dict_["value"] is not None:
            instance.value = str(dict_["value"])
        elif include_empty:
            instance.value = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ConfigInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ConfigInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ConfigInfo, List[ConfigInfo], Dict[Any, ConfigInfo]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "createdAt": "created_at",
            "key": "key",
            "namespace": "namespace",
            "updatedAt": "updated_at",
            "value": "value",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "createdAt": False,
            "key": False,
            "namespace": False,
            "updatedAt": False,
            "value": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Iam Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelResetPasswordRequestV3(Model):
    """Model reset password request V3 (model.ResetPasswordRequestV3)

    Properties:
        code: (code) REQUIRED str

        email_address: (emailAddress) REQUIRED str

        new_password: (newPassword) REQUIRED str
    """

    # region fields

    code: str  # REQUIRED
    email_address: str  # REQUIRED
    new_password: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_code(self, value: str) -> ModelResetPasswordRequestV3:
        self.code = value
        return self

    def with_email_address(self, value: str) -> ModelResetPasswordRequestV3:
        self.email_address = value
        return self

    def with_new_password(self, value: str) -> ModelResetPasswordRequestV3:
        self.new_password = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "code"):
            result["code"] = str(self.code)
        elif include_empty:
            result["code"] = ""
        if hasattr(self, "email_address"):
            result["emailAddress"] = str(self.email_address)
        elif include_empty:
            result["emailAddress"] = ""
        if hasattr(self, "new_password"):
            result["newPassword"] = str(self.new_password)
        elif include_empty:
            result["newPassword"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, code: str, email_address: str, new_password: str, **kwargs
    ) -> ModelResetPasswordRequestV3:
        instance = cls()
        instance.code = code
        instance.email_address = email_address
        instance.new_password = new_password
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelResetPasswordRequestV3:
        instance = cls()
        if not dict_:
            return instance
        if "code" in dict_ and dict_["code"] is not None:
            instance.code = str(dict_["code"])
        elif include_empty:
            instance.code = ""
        if "emailAddress" in dict_ and dict_["emailAddress"] is not None:
            instance.email_address = str(dict_["emailAddress"])
        elif include_empty:
            instance.email_address = ""
        if "newPassword" in dict_ and dict_["newPassword"] is not None:
            instance.new_password = str(dict_["newPassword"])
        elif include_empty:
            instance.new_password = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelResetPasswordRequestV3]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelResetPasswordRequestV3]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelResetPasswordRequestV3,
        List[ModelResetPasswordRequestV3],
        Dict[Any, ModelResetPasswordRequestV3],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "code": "code",
            "emailAddress": "email_address",
            "newPassword": "new_password",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "code": True,
            "emailAddress": True,
            "newPassword": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Gdpr Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class ProtocolEnum(StrEnum):
    GRPC = "GRPC"


class DtoServiceConfigDTO(Model):
    """Dto service config DTO (dto.ServiceConfigDTO)

    Properties:
        protocol: (protocol) REQUIRED Union[str, ProtocolEnum]

        url: (url) REQUIRED str

        skip_ack: (skipAck) OPTIONAL bool
    """

    # region fields

    protocol: Union[str, ProtocolEnum]  # REQUIRED
    url: str  # REQUIRED
    skip_ack: bool  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_protocol(self, value: Union[str, ProtocolEnum]) -> DtoServiceConfigDTO:
        self.protocol = value
        return self

    def with_url(self, value: str) -> DtoServiceConfigDTO:
        self.url = value
        return self

    def with_skip_ack(self, value: bool) -> DtoServiceConfigDTO:
        self.skip_ack = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "protocol"):
            result["protocol"] = str(self.protocol)
        elif include_empty:
            result["protocol"] = Union[str, ProtocolEnum]()
        if hasattr(self, "url"):
            result["url"] = str(self.url)
        elif include_empty:
            result["url"] = ""
        if hasattr(self, "skip_ack"):
            result["skipAck"] = bool(self.skip_ack)
        elif include_empty:
            result["skipAck"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        protocol: Union[str, ProtocolEnum],
        url: str,
        skip_ack: Optional[bool] = None,
        **kwargs,
    ) -> DtoServiceConfigDTO:
        instance = cls()
        instance.protocol = protocol
        instance.url = url
        if skip_ack is not None:
            instance.skip_ack = skip_ack
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> DtoServiceConfigDTO:
        instance = cls()
        if not dict_:
            return instance
        if "protocol" in dict_ and dict_["protocol"] is not None:
            instance.protocol = str(dict_["protocol"])
        elif include_empty:
            instance.protocol = Union[str, ProtocolEnum]()
        if "url" in dict_ and dict_["url"] is not None:
            instance.url = str(dict_["url"])
        elif include_empty:
            instance.url = ""
        if "skipAck" in dict_ and dict_["skipAck"] is not None:
            instance.skip_ack = bool(dict_["skipAck"])
        elif include_empty:
            instance.skip_ack = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, DtoServiceConfigDTO]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[DtoServiceConfigDTO]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        DtoServiceConfigDTO, List[DtoServiceConfigDTO], Dict[Any, DtoServiceConfigDTO]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "protocol": "protocol",
            "url": "url",
            "skipAck": "skip_ack",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "protocol": True,
            "url": True,
            "skipAck": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "protocol": ["GRPC"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Service."""

__version__ = "3.15.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_player_attributes import AdminGetPlayerAttributes
from .admin_query_player_attributes import AdminQueryPlayerAttributes
from .public_delete_player_at_57835b import PublicDeletePlayerAttributes
from .public_get_bulk_player__da8481 import PublicGetBulkPlayerCurrentPlatform
from .public_get_player_attributes import PublicGetPlayerAttributes
from .public_store_player_attributes import PublicStorePlayerAttributes



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Iam Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.model_user_ban_with_status import ModelUserBanWithStatus


class ModelGetUserBanSummaryV3(Model):
    """Model get user ban summary V3 (model.GetUserBanSummaryV3)

    Properties:
        active_count: (activeCount) REQUIRED int

        data: (data) REQUIRED List[ModelUserBanWithStatus]

        inactive_count: (inactiveCount) REQUIRED int

        total_count: (totalCount) REQUIRED int
    """

    # region fields

    active_count: int  # REQUIRED
    data: List[ModelUserBanWithStatus]  # REQUIRED
    inactive_count: int  # REQUIRED
    total_count: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_active_count(self, value: int) -> ModelGetUserBanSummaryV3:
        self.active_count = value
        return self

    def with_data(
        self, value: List[ModelUserBanWithStatus]
    ) -> ModelGetUserBanSummaryV3:
        self.data = value
        return self

    def with_inactive_count(self, value: int) -> ModelGetUserBanSummaryV3:
        self.inactive_count = value
        return self

    def with_total_count(self, value: int) -> ModelGetUserBanSummaryV3:
        self.total_count = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "active_count"):
            result["activeCount"] = int(self.active_count)
        elif include_empty:
            result["activeCount"] = 0
        if hasattr(self, "data"):
            result["data"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.data
            ]
        elif include_empty:
            result["data"] = []
        if hasattr(self, "inactive_count"):
            result["inactiveCount"] = int(self.inactive_count)
        elif include_empty:
            result["inactiveCount"] = 0
        if hasattr(self, "total_count"):
            result["totalCount"] = int(self.total_count)
        elif include_empty:
            result["totalCount"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        active_count: int,
        data: List[ModelUserBanWithStatus],
        inactive_count: int,
        total_count: int,
        **kwargs,
    ) -> ModelGetUserBanSummaryV3:
        instance = cls()
        instance.active_count = active_count
        instance.data = data
        instance.inactive_count = inactive_count
        instance.total_count = total_count
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelGetUserBanSummaryV3:
        instance = cls()
        if not dict_:
            return instance
        if "activeCount" in dict_ and dict_["activeCount"] is not None:
            instance.active_count = int(dict_["activeCount"])
        elif include_empty:
            instance.active_count = 0
        if "data" in dict_ and dict_["data"] is not None:
            instance.data = [
                ModelUserBanWithStatus.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["data"]
            ]
        elif include_empty:
            instance.data = []
        if "inactiveCount" in dict_ and dict_["inactiveCount"] is not None:
            instance.inactive_count = int(dict_["inactiveCount"])
        elif include_empty:
            instance.inactive_count = 0
        if "totalCount" in dict_ and dict_["totalCount"] is not None:
            instance.total_count = int(dict_["totalCount"])
        elif include_empty:
            instance.total_count = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelGetUserBanSummaryV3]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelGetUserBanSummaryV3]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelGetUserBanSummaryV3,
        List[ModelGetUserBanSummaryV3],
        Dict[Any, ModelGetUserBanSummaryV3],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "activeCount": "active_count",
            "data": "data",
            "inactiveCount": "inactive_count",
            "totalCount": "total_count",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "activeCount": True,
            "data": True,
            "inactiveCount": True,
            "totalCount": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsMemberActiveSession
from ..models import ModelsRequestReconcileMaxActiveSession
from ..models import ResponseError

from ..operations.max_active import AdminGetMemberActiveSession
from ..operations.max_active import AdminReconcileMaxActiveSession


@same_doc_as(AdminGetMemberActiveSession)
def admin_get_member_active_session(
    name: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Member Active Session. (adminGetMemberActiveSession)


    Get Member Active Session.

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/configurations/{name}/memberactivesession/{userId}

        method: GET

        tags: ["Max Active"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        name: (name) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsMemberActiveSession (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetMemberActiveSession.create(
        name=name,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetMemberActiveSession)
async def admin_get_member_active_session_async(
    name: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Member Active Session. (adminGetMemberActiveSession)


    Get Member Active Session.

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/configurations/{name}/memberactivesession/{userId}

        method: GET

        tags: ["Max Active"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        name: (name) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsMemberActiveSession (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetMemberActiveSession.create(
        name=name,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminReconcileMaxActiveSession)
def admin_reconcile_max_active_session(
    body: ModelsRequestReconcileMaxActiveSession,
    name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Reconcile Max Active Session. (adminReconcileMaxActiveSession)


    Reconcile Max Active Session.

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/configurations/{name}/reconcile

        method: POST

        tags: ["Max Active"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsRequestReconcileMaxActiveSession in body

        name: (name) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminReconcileMaxActiveSession.create(
        body=body,
        name=name,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminReconcileMaxActiveSession)
async def admin_reconcile_max_active_session_async(
    body: ModelsRequestReconcileMaxActiveSession,
    name: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Reconcile Max Active Session. (adminReconcileMaxActiveSession)


    Reconcile Max Active Session.

    Properties:
        url: /session/v1/admin/namespaces/{namespace}/configurations/{name}/reconcile

        method: POST

        tags: ["Max Active"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsRequestReconcileMaxActiveSession in body

        name: (name) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminReconcileMaxActiveSession.create(
        body=body,
        name=name,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class TypeEnum(StrEnum):
    TOPIC_CREATE = "TOPIC_CREATE"
    TOPIC_DELETE = "TOPIC_DELETE"
    TOPIC_JOIN = "TOPIC_JOIN"
    TOPIC_LEAVE = "TOPIC_LEAVE"


class ModelsTopicLogItem(Model):
    """Models topic log item (models.TopicLogItem)

    Properties:
        created_at: (createdAt) REQUIRED int

        id_: (id) REQUIRED str

        message: (message) REQUIRED str

        sender_id: (senderId) REQUIRED str

        topic_id: (topicId) REQUIRED str

        type_: (type) REQUIRED Union[str, TypeEnum]

        user_id: (userId) REQUIRED str
    """

    # region fields

    created_at: int  # REQUIRED
    id_: str  # REQUIRED
    message: str  # REQUIRED
    sender_id: str  # REQUIRED
    topic_id: str  # REQUIRED
    type_: Union[str, TypeEnum]  # REQUIRED
    user_id: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: int) -> ModelsTopicLogItem:
        self.created_at = value
        return self

    def with_id(self, value: str) -> ModelsTopicLogItem:
        self.id_ = value
        return self

    def with_message(self, value: str) -> ModelsTopicLogItem:
        self.message = value
        return self

    def with_sender_id(self, value: str) -> ModelsTopicLogItem:
        self.sender_id = value
        return self

    def with_topic_id(self, value: str) -> ModelsTopicLogItem:
        self.topic_id = value
        return self

    def with_type(self, value: Union[str, TypeEnum]) -> ModelsTopicLogItem:
        self.type_ = value
        return self

    def with_user_id(self, value: str) -> ModelsTopicLogItem:
        self.user_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["createdAt"] = int(self.created_at)
        elif include_empty:
            result["createdAt"] = 0
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "message"):
            result["message"] = str(self.message)
        elif include_empty:
            result["message"] = ""
        if hasattr(self, "sender_id"):
            result["senderId"] = str(self.sender_id)
        elif include_empty:
            result["senderId"] = ""
        if hasattr(self, "topic_id"):
            result["topicId"] = str(self.topic_id)
        elif include_empty:
            result["topicId"] = ""
        if hasattr(self, "type_"):
            result["type"] = str(self.type_)
        elif include_empty:
            result["type"] = Union[str, TypeEnum]()
        if hasattr(self, "user_id"):
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: int,
        id_: str,
        message: str,
        sender_id: str,
        topic_id: str,
        type_: Union[str, TypeEnum],
        user_id: str,
        **kwargs,
    ) -> ModelsTopicLogItem:
        instance = cls()
        instance.created_at = created_at
        instance.id_ = id_
        instance.message = message
        instance.sender_id = sender_id
        instance.topic_id = topic_id
        instance.type_ = type_
        instance.user_id = user_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsTopicLogItem:
        instance = cls()
        if not dict_:
            return instance
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = int(dict_["createdAt"])
        elif include_empty:
            instance.created_at = 0
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "message" in dict_ and dict_["message"] is not None:
            instance.message = str(dict_["message"])
        elif include_empty:
            instance.message = ""
        if "senderId" in dict_ and dict_["senderId"] is not None:
            instance.sender_id = str(dict_["senderId"])
        elif include_empty:
            instance.sender_id = ""
        if "topicId" in dict_ and dict_["topicId"] is not None:
            instance.topic_id = str(dict_["topicId"])
        elif include_empty:
            instance.topic_id = ""
        if "type" in dict_ and dict_["type"] is not None:
            instance.type_ = str(dict_["type"])
        elif include_empty:
            instance.type_ = Union[str, TypeEnum]()
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsTopicLogItem]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsTopicLogItem]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsTopicLogItem, List[ModelsTopicLogItem], Dict[Any, ModelsTopicLogItem]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "createdAt": "created_at",
            "id": "id_",
            "message": "message",
            "senderId": "sender_id",
            "topicId": "topic_id",
            "type": "type_",
            "userId": "user_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "createdAt": True,
            "id": True,
            "message": True,
            "senderId": True,
            "topicId": True,
            "type": True,
            "userId": True,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "type": ["TOPIC_CREATE", "TOPIC_DELETE", "TOPIC_JOIN", "TOPIC_LEAVE"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.time_limited_balance import TimeLimitedBalance


class SimpleWallet(Model):
    """Simple wallet (SimpleWallet)

    Properties:
        balance: (balance) OPTIONAL int

        balance_origin: (balanceOrigin) OPTIONAL str

        currency_code: (currencyCode) OPTIONAL str

        time_limited_balances: (timeLimitedBalances) OPTIONAL List[TimeLimitedBalance]

        wallet_id: (walletId) OPTIONAL str
    """

    # region fields

    balance: int  # OPTIONAL
    balance_origin: str  # OPTIONAL
    currency_code: str  # OPTIONAL
    time_limited_balances: List[TimeLimitedBalance]  # OPTIONAL
    wallet_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_balance(self, value: int) -> SimpleWallet:
        self.balance = value
        return self

    def with_balance_origin(self, value: str) -> SimpleWallet:
        self.balance_origin = value
        return self

    def with_currency_code(self, value: str) -> SimpleWallet:
        self.currency_code = value
        return self

    def with_time_limited_balances(
        self, value: List[TimeLimitedBalance]
    ) -> SimpleWallet:
        self.time_limited_balances = value
        return self

    def with_wallet_id(self, value: str) -> SimpleWallet:
        self.wallet_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "balance"):
            result["balance"] = int(self.balance)
        elif include_empty:
            result["balance"] = 0
        if hasattr(self, "balance_origin"):
            result["balanceOrigin"] = str(self.balance_origin)
        elif include_empty:
            result["balanceOrigin"] = ""
        if hasattr(self, "currency_code"):
            result["currencyCode"] = str(self.currency_code)
        elif include_empty:
            result["currencyCode"] = ""
        if hasattr(self, "time_limited_balances"):
            result["timeLimitedBalances"] = [
                i0.to_dict(include_empty=include_empty)
                for i0 in self.time_limited_balances
            ]
        elif include_empty:
            result["timeLimitedBalances"] = []
        if hasattr(self, "wallet_id"):
            result["walletId"] = str(self.wallet_id)
        elif include_empty:
            result["walletId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        balance: Optional[int] = None,
        balance_origin: Optional[str] = None,
        currency_code: Optional[str] = None,
        time_limited_balances: Optional[List[TimeLimitedBalance]] = None,
        wallet_id: Optional[str] = None,
        **kwargs,
    ) -> SimpleWallet:
        instance = cls()
        if balance is not None:
            instance.balance = balance
        if balance_origin is not None:
            instance.balance_origin = balance_origin
        if currency_code is not None:
            instance.currency_code = currency_code
        if time_limited_balances is not None:
            instance.time_limited_balances = time_limited_balances
        if wallet_id is not None:
            instance.wallet_id = wallet_id
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> SimpleWallet:
        instance = cls()
        if not dict_:
            return instance
        if "balance" in dict_ and dict_["balance"] is not None:
            instance.balance = int(dict_["balance"])
        elif include_empty:
            instance.balance = 0
        if "balanceOrigin" in dict_ and dict_["balanceOrigin"] is not None:
            instance.balance_origin = str(dict_["balanceOrigin"])
        elif include_empty:
            instance.balance_origin = ""
        if "currencyCode" in dict_ and dict_["currencyCode"] is not None:
            instance.currency_code = str(dict_["currencyCode"])
        elif include_empty:
            instance.currency_code = ""
        if "timeLimitedBalances" in dict_ and dict_["timeLimitedBalances"] is not None:
            instance.time_limited_balances = [
                TimeLimitedBalance.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["timeLimitedBalances"]
            ]
        elif include_empty:
            instance.time_limited_balances = []
        if "walletId" in dict_ and dict_["walletId"] is not None:
            instance.wallet_id = str(dict_["walletId"])
        elif include_empty:
            instance.wallet_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, SimpleWallet]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[SimpleWallet]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[SimpleWallet, List[SimpleWallet], Dict[Any, SimpleWallet]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "balance": "balance",
            "balanceOrigin": "balance_origin",
            "currencyCode": "currency_code",
            "timeLimitedBalances": "time_limited_balances",
            "walletId": "wallet_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "balance": False,
            "balanceOrigin": False,
            "currencyCode": False,
            "timeLimitedBalances": False,
            "walletId": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApiFleetClaimByKeysReq
from ..models import ApiFleetClaimReq
from ..models import ApiFleetClaimResponse
from ..models import ApiFleetCreateResponse
from ..models import ApiFleetGetResponse
from ..models import ApiFleetListResponse
from ..models import ApiFleetParameters
from ..models import ApiFleetServersResponse
from ..models import ResponseErrorResponse

from ..operations.fleets import FleetClaimByID
from ..operations.fleets import FleetClaimByKeys
from ..operations.fleets import FleetCreate
from ..operations.fleets import FleetDelete
from ..operations.fleets import FleetGet
from ..operations.fleets import FleetList
from ..operations.fleets import FleetServers
from ..operations.fleets import FleetUpdate


@same_doc_as(FleetClaimByID)
def fleet_claim_by_id(
    body: ApiFleetClaimReq,
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """claim a dedicated server from a fleet (FleetClaimByID)

    Required Permission: NAMESPACE:{namespace}:AMS:SERVER:CLAIM [UPDATE]

    Required Permission(s):
        - NAMESPACE:{namespace}:AMS:SERVER:CLAIM [UPDATE]

    Properties:
        url: /ams/v1/namespaces/{namespace}/fleets/{fleetID}/claim

        method: PUT

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiFleetClaimReq in body

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetClaimResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetClaimByID.create(
        body=body,
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetClaimByID)
async def fleet_claim_by_id_async(
    body: ApiFleetClaimReq,
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """claim a dedicated server from a fleet (FleetClaimByID)

    Required Permission: NAMESPACE:{namespace}:AMS:SERVER:CLAIM [UPDATE]

    Required Permission(s):
        - NAMESPACE:{namespace}:AMS:SERVER:CLAIM [UPDATE]

    Properties:
        url: /ams/v1/namespaces/{namespace}/fleets/{fleetID}/claim

        method: PUT

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiFleetClaimReq in body

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetClaimResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetClaimByID.create(
        body=body,
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(FleetClaimByKeys)
def fleet_claim_by_keys(
    body: ApiFleetClaimByKeysReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """claim a dedicated server (FleetClaimByKeys)

    Claim a dedicated server from fleets with matching claim keys

    Required Permission: NAMESPACE:{namespace}:AMS:SERVER:CLAIM [UPDATE]

    Required Permission(s):
        - NAMESPACE:{namespace}:AMS:SERVER:CLAIM [UPDATE]

    Properties:
        url: /ams/v1/namespaces/{namespace}/servers/claim

        method: PUT

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiFleetClaimByKeysReq in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetClaimResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (no matching DS available)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetClaimByKeys.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetClaimByKeys)
async def fleet_claim_by_keys_async(
    body: ApiFleetClaimByKeysReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """claim a dedicated server (FleetClaimByKeys)

    Claim a dedicated server from fleets with matching claim keys

    Required Permission: NAMESPACE:{namespace}:AMS:SERVER:CLAIM [UPDATE]

    Required Permission(s):
        - NAMESPACE:{namespace}:AMS:SERVER:CLAIM [UPDATE]

    Properties:
        url: /ams/v1/namespaces/{namespace}/servers/claim

        method: PUT

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiFleetClaimByKeysReq in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetClaimResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (no matching DS available)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetClaimByKeys.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(FleetCreate)
def fleet_create(
    body: ApiFleetParameters,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """create a fleet (FleetCreate)

    Optionally, sampling rules for the fleet can also be specified

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [CREATE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [CREATE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets

        method: POST

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiFleetParameters in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApiFleetCreateResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (exceeded quota)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetCreate.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetCreate)
async def fleet_create_async(
    body: ApiFleetParameters,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """create a fleet (FleetCreate)

    Optionally, sampling rules for the fleet can also be specified

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [CREATE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [CREATE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets

        method: POST

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiFleetParameters in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApiFleetCreateResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (exceeded quota)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetCreate.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(FleetDelete)
def fleet_delete(
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """delete a fleet (FleetDelete)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [DELETE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [DELETE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}

        method: DELETE

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (no content)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetDelete.create(
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetDelete)
async def fleet_delete_async(
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """delete a fleet (FleetDelete)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [DELETE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [DELETE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}

        method: DELETE

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (no content)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetDelete.create(
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(FleetGet)
def fleet_get(
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get a fleet (FleetGet)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}

        method: GET

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetGetResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetGet.create(
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetGet)
async def fleet_get_async(
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get a fleet (FleetGet)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}

        method: GET

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetGetResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetGet.create(
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(FleetList)
def fleet_list(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """list all fleets in a namespace (FleetList)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets

        method: GET

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetListResponse (success)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetList.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetList)
async def fleet_list_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """list all fleets in a namespace (FleetList)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets

        method: GET

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetListResponse (success)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetList.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(FleetServers)
def fleet_servers(
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get server details & counts for a fleet (FleetServers)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}/servers

        method: GET

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetServersResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetServers.create(
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetServers)
async def fleet_servers_async(
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get server details & counts for a fleet (FleetServers)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}/servers

        method: GET

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiFleetServersResponse (success)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetServers.create(
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(FleetUpdate)
def fleet_update(
    body: ApiFleetParameters,
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """update a fleet -– overrides current data (FleetUpdate)

    Optionally, sampling rules for the fleet can also be updated

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [UPDATE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [UPDATE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}

        method: PUT

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiFleetParameters in body

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (no content)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetUpdate.create(
        body=body,
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(FleetUpdate)
async def fleet_update_async(
    body: ApiFleetParameters,
    fleet_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """update a fleet -– overrides current data (FleetUpdate)

    Optionally, sampling rules for the fleet can also be updated

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [UPDATE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:FLEET [UPDATE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/fleets/{fleetID}

        method: PUT

        tags: ["Fleets"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiFleetParameters in body

        fleet_id: (fleetID) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (no content)

        400: Bad Request - ResponseErrorResponse (bad request)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (fleet not found)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = FleetUpdate.create(
        body=body,
        fleet_id=fleet_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Leaderboard Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.models_daily_config import ModelsDailyConfig
from ..models.models_monthly_config import ModelsMonthlyConfig
from ..models.models_weekly_config import ModelsWeeklyConfig


class ModelsUpdateLeaderboardConfigReq(Model):
    """Models update leaderboard config req (models.UpdateLeaderboardConfigReq)

    Properties:
        daily: (daily) REQUIRED ModelsDailyConfig

        descending: (descending) REQUIRED bool

        icon_url: (iconURL) REQUIRED str

        monthly: (monthly) REQUIRED ModelsMonthlyConfig

        name: (name) REQUIRED str

        season_period: (seasonPeriod) REQUIRED int

        start_time: (startTime) REQUIRED str

        stat_code: (statCode) REQUIRED str

        weekly: (weekly) REQUIRED ModelsWeeklyConfig
    """

    # region fields

    daily: ModelsDailyConfig  # REQUIRED
    descending: bool  # REQUIRED
    icon_url: str  # REQUIRED
    monthly: ModelsMonthlyConfig  # REQUIRED
    name: str  # REQUIRED
    season_period: int  # REQUIRED
    start_time: str  # REQUIRED
    stat_code: str  # REQUIRED
    weekly: ModelsWeeklyConfig  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_daily(self, value: ModelsDailyConfig) -> ModelsUpdateLeaderboardConfigReq:
        self.daily = value
        return self

    def with_descending(self, value: bool) -> ModelsUpdateLeaderboardConfigReq:
        self.descending = value
        return self

    def with_icon_url(self, value: str) -> ModelsUpdateLeaderboardConfigReq:
        self.icon_url = value
        return self

    def with_monthly(
        self, value: ModelsMonthlyConfig
    ) -> ModelsUpdateLeaderboardConfigReq:
        self.monthly = value
        return self

    def with_name(self, value: str) -> ModelsUpdateLeaderboardConfigReq:
        self.name = value
        return self

    def with_season_period(self, value: int) -> ModelsUpdateLeaderboardConfigReq:
        self.season_period = value
        return self

    def with_start_time(self, value: str) -> ModelsUpdateLeaderboardConfigReq:
        self.start_time = value
        return self

    def with_stat_code(self, value: str) -> ModelsUpdateLeaderboardConfigReq:
        self.stat_code = value
        return self

    def with_weekly(
        self, value: ModelsWeeklyConfig
    ) -> ModelsUpdateLeaderboardConfigReq:
        self.weekly = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "daily"):
            result["daily"] = self.daily.to_dict(include_empty=include_empty)
        elif include_empty:
            result["daily"] = ModelsDailyConfig()
        if hasattr(self, "descending"):
            result["descending"] = bool(self.descending)
        elif include_empty:
            result["descending"] = False
        if hasattr(self, "icon_url"):
            result["iconURL"] = str(self.icon_url)
        elif include_empty:
            result["iconURL"] = ""
        if hasattr(self, "monthly"):
            result["monthly"] = self.monthly.to_dict(include_empty=include_empty)
        elif include_empty:
            result["monthly"] = ModelsMonthlyConfig()
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "season_period"):
            result["seasonPeriod"] = int(self.season_period)
        elif include_empty:
            result["seasonPeriod"] = 0
        if hasattr(self, "start_time"):
            result["startTime"] = str(self.start_time)
        elif include_empty:
            result["startTime"] = ""
        if hasattr(self, "stat_code"):
            result["statCode"] = str(self.stat_code)
        elif include_empty:
            result["statCode"] = ""
        if hasattr(self, "weekly"):
            result["weekly"] = self.weekly.to_dict(include_empty=include_empty)
        elif include_empty:
            result["weekly"] = ModelsWeeklyConfig()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        daily: ModelsDailyConfig,
        descending: bool,
        icon_url: str,
        monthly: ModelsMonthlyConfig,
        name: str,
        season_period: int,
        start_time: str,
        stat_code: str,
        weekly: ModelsWeeklyConfig,
        **kwargs,
    ) -> ModelsUpdateLeaderboardConfigReq:
        instance = cls()
        instance.daily = daily
        instance.descending = descending
        instance.icon_url = icon_url
        instance.monthly = monthly
        instance.name = name
        instance.season_period = season_period
        instance.start_time = start_time
        instance.stat_code = stat_code
        instance.weekly = weekly
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsUpdateLeaderboardConfigReq:
        instance = cls()
        if not dict_:
            return instance
        if "daily" in dict_ and dict_["daily"] is not None:
            instance.daily = ModelsDailyConfig.create_from_dict(
                dict_["daily"], include_empty=include_empty
            )
        elif include_empty:
            instance.daily = ModelsDailyConfig()
        if "descending" in dict_ and dict_["descending"] is not None:
            instance.descending = bool(dict_["descending"])
        elif include_empty:
            instance.descending = False
        if "iconURL" in dict_ and dict_["iconURL"] is not None:
            instance.icon_url = str(dict_["iconURL"])
        elif include_empty:
            instance.icon_url = ""
        if "monthly" in dict_ and dict_["monthly"] is not None:
            instance.monthly = ModelsMonthlyConfig.create_from_dict(
                dict_["monthly"], include_empty=include_empty
            )
        elif include_empty:
            instance.monthly = ModelsMonthlyConfig()
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "seasonPeriod" in dict_ and dict_["seasonPeriod"] is not None:
            instance.season_period = int(dict_["seasonPeriod"])
        elif include_empty:
            instance.season_period = 0
        if "startTime" in dict_ and dict_["startTime"] is not None:
            instance.start_time = str(dict_["startTime"])
        elif include_empty:
            instance.start_time = ""
        if "statCode" in dict_ and dict_["statCode"] is not None:
            instance.stat_code = str(dict_["statCode"])
        elif include_empty:
            instance.stat_code = ""
        if "weekly" in dict_ and dict_["weekly"] is not None:
            instance.weekly = ModelsWeeklyConfig.create_from_dict(
                dict_["weekly"], include_empty=include_empty
            )
        elif include_empty:
            instance.weekly = ModelsWeeklyConfig()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsUpdateLeaderboardConfigReq]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsUpdateLeaderboardConfigReq]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsUpdateLeaderboardConfigReq,
        List[ModelsUpdateLeaderboardConfigReq],
        Dict[Any, ModelsUpdateLeaderboardConfigReq],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "daily": "daily",
            "descending": "descending",
            "iconURL": "icon_url",
            "monthly": "monthly",
            "name": "name",
            "seasonPeriod": "season_period",
            "startTime": "start_time",
            "statCode": "stat_code",
            "weekly": "weekly",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "daily": True,
            "descending": True,
            "iconURL": True,
            "monthly": True,
            "name": True,
            "seasonPeriod": True,
            "startTime": True,
            "statCode": True,
            "weekly": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsServerLogs
from ..models import ResponseError

from ..operations.admin import GetServerLogs


@same_doc_as(GetServerLogs)
def get_server_logs(
    pod_name: str,
    log_type: Optional[str] = None,
    offset: Optional[int] = None,
    origin: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Queries server logs (getServerLogs)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSM:SERVER [READ]

    Required scope: social

    This endpoint queries a specified dedicated server's logs.

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSM:SERVER [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dslogmanager/admin/namespaces/{namespace}/servers/{podName}/logs

        method: GET

        tags: ["Admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

        log_type: (logType) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        origin: (origin) OPTIONAL str in query

    Responses:
        200: OK - ModelsServerLogs (server logs queried)

        400: Bad Request - ResponseError (malformed request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (server not found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetServerLogs.create(
        pod_name=pod_name,
        log_type=log_type,
        offset=offset,
        origin=origin,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetServerLogs)
async def get_server_logs_async(
    pod_name: str,
    log_type: Optional[str] = None,
    offset: Optional[int] = None,
    origin: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Queries server logs (getServerLogs)

    Required permission: ADMIN:NAMESPACE:{namespace}:DSM:SERVER [READ]

    Required scope: social

    This endpoint queries a specified dedicated server's logs.

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DSM:SERVER [READ]

    Required Scope(s):
        - social

    Properties:
        url: /dslogmanager/admin/namespaces/{namespace}/servers/{podName}/logs

        method: GET

        tags: ["Admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

        log_type: (logType) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        origin: (origin) OPTIONAL str in query

    Responses:
        200: OK - ModelsServerLogs (server logs queried)

        400: Bad Request - ResponseError (malformed request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (server not found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetServerLogs.create(
        pod_name=pod_name,
        log_type=log_type,
        offset=offset,
        origin=origin,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Statistics Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class SetByEnum(StrEnum):
    CLIENT = "CLIENT"
    SERVER = "SERVER"


class StatusEnum(StrEnum):
    INIT = "INIT"
    TIED = "TIED"


class GlobalAggregationMethodEnum(StrEnum):
    LAST = "LAST"
    MAX = "MAX"
    MIN = "MIN"
    TOTAL = "TOTAL"


class StatInfo(Model):
    """Stat info (StatInfo)

    Properties:
        created_at: (createdAt) REQUIRED str

        default_value: (defaultValue) REQUIRED float

        ignore_additional_data_on_value_rejected: (ignoreAdditionalDataOnValueRejected) REQUIRED bool

        increment_only: (incrementOnly) REQUIRED bool

        is_public: (isPublic) REQUIRED bool

        name: (name) REQUIRED str

        namespace: (namespace) REQUIRED str

        set_as_global: (setAsGlobal) REQUIRED bool

        set_by: (setBy) REQUIRED Union[str, SetByEnum]

        stat_code: (statCode) REQUIRED str

        status: (status) REQUIRED Union[str, StatusEnum]

        updated_at: (updatedAt) REQUIRED str

        cycle_ids: (cycleIds) OPTIONAL List[str]

        description: (description) OPTIONAL str

        global_aggregation_method: (globalAggregationMethod) OPTIONAL Union[str, GlobalAggregationMethodEnum]

        maximum: (maximum) OPTIONAL float

        minimum: (minimum) OPTIONAL float

        tags: (tags) OPTIONAL List[str]
    """

    # region fields

    created_at: str  # REQUIRED
    default_value: float  # REQUIRED
    ignore_additional_data_on_value_rejected: bool  # REQUIRED
    increment_only: bool  # REQUIRED
    is_public: bool  # REQUIRED
    name: str  # REQUIRED
    namespace: str  # REQUIRED
    set_as_global: bool  # REQUIRED
    set_by: Union[str, SetByEnum]  # REQUIRED
    stat_code: str  # REQUIRED
    status: Union[str, StatusEnum]  # REQUIRED
    updated_at: str  # REQUIRED
    cycle_ids: List[str]  # OPTIONAL
    description: str  # OPTIONAL
    global_aggregation_method: Union[str, GlobalAggregationMethodEnum]  # OPTIONAL
    maximum: float  # OPTIONAL
    minimum: float  # OPTIONAL
    tags: List[str]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: str) -> StatInfo:
        self.created_at = value
        return self

    def with_default_value(self, value: float) -> StatInfo:
        self.default_value = value
        return self

    def with_ignore_additional_data_on_value_rejected(self, value: bool) -> StatInfo:
        self.ignore_additional_data_on_value_rejected = value
        return self

    def with_increment_only(self, value: bool) -> StatInfo:
        self.increment_only = value
        return self

    def with_is_public(self, value: bool) -> StatInfo:
        self.is_public = value
        return self

    def with_name(self, value: str) -> StatInfo:
        self.name = value
        return self

    def with_namespace(self, value: str) -> StatInfo:
        self.namespace = value
        return self

    def with_set_as_global(self, value: bool) -> StatInfo:
        self.set_as_global = value
        return self

    def with_set_by(self, value: Union[str, SetByEnum]) -> StatInfo:
        self.set_by = value
        return self

    def with_stat_code(self, value: str) -> StatInfo:
        self.stat_code = value
        return self

    def with_status(self, value: Union[str, StatusEnum]) -> StatInfo:
        self.status = value
        return self

    def with_updated_at(self, value: str) -> StatInfo:
        self.updated_at = value
        return self

    def with_cycle_ids(self, value: List[str]) -> StatInfo:
        self.cycle_ids = value
        return self

    def with_description(self, value: str) -> StatInfo:
        self.description = value
        return self

    def with_global_aggregation_method(
        self, value: Union[str, GlobalAggregationMethodEnum]
    ) -> StatInfo:
        self.global_aggregation_method = value
        return self

    def with_maximum(self, value: float) -> StatInfo:
        self.maximum = value
        return self

    def with_minimum(self, value: float) -> StatInfo:
        self.minimum = value
        return self

    def with_tags(self, value: List[str]) -> StatInfo:
        self.tags = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "default_value"):
            result["defaultValue"] = float(self.default_value)
        elif include_empty:
            result["defaultValue"] = 0.0
        if hasattr(self, "ignore_additional_data_on_value_rejected"):
            result["ignoreAdditionalDataOnValueRejected"] = bool(
                self.ignore_additional_data_on_value_rejected
            )
        elif include_empty:
            result["ignoreAdditionalDataOnValueRejected"] = False
        if hasattr(self, "increment_only"):
            result["incrementOnly"] = bool(self.increment_only)
        elif include_empty:
            result["incrementOnly"] = False
        if hasattr(self, "is_public"):
            result["isPublic"] = bool(self.is_public)
        elif include_empty:
            result["isPublic"] = False
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "set_as_global"):
            result["setAsGlobal"] = bool(self.set_as_global)
        elif include_empty:
            result["setAsGlobal"] = False
        if hasattr(self, "set_by"):
            result["setBy"] = str(self.set_by)
        elif include_empty:
            result["setBy"] = Union[str, SetByEnum]()
        if hasattr(self, "stat_code"):
            result["statCode"] = str(self.stat_code)
        elif include_empty:
            result["statCode"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        if hasattr(self, "updated_at"):
            result["updatedAt"] = str(self.updated_at)
        elif include_empty:
            result["updatedAt"] = ""
        if hasattr(self, "cycle_ids"):
            result["cycleIds"] = [str(i0) for i0 in self.cycle_ids]
        elif include_empty:
            result["cycleIds"] = []
        if hasattr(self, "description"):
            result["description"] = str(self.description)
        elif include_empty:
            result["description"] = ""
        if hasattr(self, "global_aggregation_method"):
            result["globalAggregationMethod"] = str(self.global_aggregation_method)
        elif include_empty:
            result["globalAggregationMethod"] = Union[
                str, GlobalAggregationMethodEnum
            ]()
        if hasattr(self, "maximum"):
            result["maximum"] = float(self.maximum)
        elif include_empty:
            result["maximum"] = 0.0
        if hasattr(self, "minimum"):
            result["minimum"] = float(self.minimum)
        elif include_empty:
            result["minimum"] = 0.0
        if hasattr(self, "tags"):
            result["tags"] = [str(i0) for i0 in self.tags]
        elif include_empty:
            result["tags"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: str,
        default_value: float,
        ignore_additional_data_on_value_rejected: bool,
        increment_only: bool,
        is_public: bool,
        name: str,
        namespace: str,
        set_as_global: bool,
        set_by: Union[str, SetByEnum],
        stat_code: str,
        status: Union[str, StatusEnum],
        updated_at: str,
        cycle_ids: Optional[List[str]] = None,
        description: Optional[str] = None,
        global_aggregation_method: Optional[
            Union[str, GlobalAggregationMethodEnum]
        ] = None,
        maximum: Optional[float] = None,
        minimum: Optional[float] = None,
        tags: Optional[List[str]] = None,
        **kwargs,
    ) -> StatInfo:
        instance = cls()
        instance.created_at = created_at
        instance.default_value = default_value
        instance.ignore_additional_data_on_value_rejected = (
            ignore_additional_data_on_value_rejected
        )
        instance.increment_only = increment_only
        instance.is_public = is_public
        instance.name = name
        instance.namespace = namespace
        instance.set_as_global = set_as_global
        instance.set_by = set_by
        instance.stat_code = stat_code
        instance.status = status
        instance.updated_at = updated_at
        if cycle_ids is not None:
            instance.cycle_ids = cycle_ids
        if description is not None:
            instance.description = description
        if global_aggregation_method is not None:
            instance.global_aggregation_method = global_aggregation_method
        if maximum is not None:
            instance.maximum = maximum
        if minimum is not None:
            instance.minimum = minimum
        if tags is not None:
            instance.tags = tags
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> StatInfo:
        instance = cls()
        if not dict_:
            return instance
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "defaultValue" in dict_ and dict_["defaultValue"] is not None:
            instance.default_value = float(dict_["defaultValue"])
        elif include_empty:
            instance.default_value = 0.0
        if (
            "ignoreAdditionalDataOnValueRejected" in dict_
            and dict_["ignoreAdditionalDataOnValueRejected"] is not None
        ):
            instance.ignore_additional_data_on_value_rejected = bool(
                dict_["ignoreAdditionalDataOnValueRejected"]
            )
        elif include_empty:
            instance.ignore_additional_data_on_value_rejected = False
        if "incrementOnly" in dict_ and dict_["incrementOnly"] is not None:
            instance.increment_only = bool(dict_["incrementOnly"])
        elif include_empty:
            instance.increment_only = False
        if "isPublic" in dict_ and dict_["isPublic"] is not None:
            instance.is_public = bool(dict_["isPublic"])
        elif include_empty:
            instance.is_public = False
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "setAsGlobal" in dict_ and dict_["setAsGlobal"] is not None:
            instance.set_as_global = bool(dict_["setAsGlobal"])
        elif include_empty:
            instance.set_as_global = False
        if "setBy" in dict_ and dict_["setBy"] is not None:
            instance.set_by = str(dict_["setBy"])
        elif include_empty:
            instance.set_by = Union[str, SetByEnum]()
        if "statCode" in dict_ and dict_["statCode"] is not None:
            instance.stat_code = str(dict_["statCode"])
        elif include_empty:
            instance.stat_code = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = str(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = ""
        if "cycleIds" in dict_ and dict_["cycleIds"] is not None:
            instance.cycle_ids = [str(i0) for i0 in dict_["cycleIds"]]
        elif include_empty:
            instance.cycle_ids = []
        if "description" in dict_ and dict_["description"] is not None:
            instance.description = str(dict_["description"])
        elif include_empty:
            instance.description = ""
        if (
            "globalAggregationMethod" in dict_
            and dict_["globalAggregationMethod"] is not None
        ):
            instance.global_aggregation_method = str(dict_["globalAggregationMethod"])
        elif include_empty:
            instance.global_aggregation_method = Union[
                str, GlobalAggregationMethodEnum
            ]()
        if "maximum" in dict_ and dict_["maximum"] is not None:
            instance.maximum = float(dict_["maximum"])
        elif include_empty:
            instance.maximum = 0.0
        if "minimum" in dict_ and dict_["minimum"] is not None:
            instance.minimum = float(dict_["minimum"])
        elif include_empty:
            instance.minimum = 0.0
        if "tags" in dict_ and dict_["tags"] is not None:
            instance.tags = [str(i0) for i0 in dict_["tags"]]
        elif include_empty:
            instance.tags = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, StatInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[StatInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[StatInfo, List[StatInfo], Dict[Any, StatInfo]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "createdAt": "created_at",
            "defaultValue": "default_value",
            "ignoreAdditionalDataOnValueRejected": "ignore_additional_data_on_value_rejected",
            "incrementOnly": "increment_only",
            "isPublic": "is_public",
            "name": "name",
            "namespace": "namespace",
            "setAsGlobal": "set_as_global",
            "setBy": "set_by",
            "statCode": "stat_code",
            "status": "status",
            "updatedAt": "updated_at",
            "cycleIds": "cycle_ids",
            "description": "description",
            "globalAggregationMethod": "global_aggregation_method",
            "maximum": "maximum",
            "minimum": "minimum",
            "tags": "tags",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "createdAt": True,
            "defaultValue": True,
            "ignoreAdditionalDataOnValueRejected": True,
            "incrementOnly": True,
            "isPublic": True,
            "name": True,
            "namespace": True,
            "setAsGlobal": True,
            "setBy": True,
            "statCode": True,
            "status": True,
            "updatedAt": True,
            "cycleIds": False,
            "description": False,
            "globalAggregationMethod": False,
            "maximum": False,
            "minimum": False,
            "tags": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "setBy": ["CLIENT", "SERVER"],
            "status": ["INIT", "TIED"],
            "globalAggregationMethod": ["LAST", "MAX", "MIN", "TOTAL"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Inventory Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.inventory.models import ApimodelsAdminUpdateItemReq
from ..api.inventory.models import ApimodelsChainingOperationReq
from ..api.inventory.models import ApimodelsChainingOperationResp
from ..api.inventory.models import ApimodelsConsumeItem
from ..api.inventory.models import ApimodelsConsumeItemReq
from ..api.inventory.models import ApimodelsCreateIntegrationConfigurationReq
from ..api.inventory.models import ApimodelsCreateInventoryConfigurationReq
from ..api.inventory.models import ApimodelsCreateInventoryReq
from ..api.inventory.models import ApimodelsCreateItem
from ..api.inventory.models import ApimodelsCreateItemTypeReq
from ..api.inventory.models import ApimodelsCreateItemTypeResp
from ..api.inventory.models import ApimodelsCreateTagReq
from ..api.inventory.models import ApimodelsCreateTagResp
from ..api.inventory.models import ApimodelsDeleteInventoryReq
from ..api.inventory.models import ApimodelsErrorResponse
from ..api.inventory.models import ApimodelsIntegrationConfigurationResp
from ..api.inventory.models import ApimodelsInventoryConfig
from ..api.inventory.models import ApimodelsInventoryConfigurationReq
from ..api.inventory.models import ApimodelsInventoryConfigurationResp
from ..api.inventory.models import ApimodelsInventoryResp
from ..api.inventory.models import ApimodelsItemResp
from ..api.inventory.models import ApimodelsListIntegrationConfigurationsResp
from ..api.inventory.models import ApimodelsListInventoryConfigurationsResp
from ..api.inventory.models import ApimodelsListInventoryResp
from ..api.inventory.models import ApimodelsListItemResp
from ..api.inventory.models import ApimodelsListItemTypesResp
from ..api.inventory.models import ApimodelsListTagsResp
from ..api.inventory.models import ApimodelsMoveItemsReq
from ..api.inventory.models import ApimodelsMoveItemsResp
from ..api.inventory.models import ApimodelsOperation
from ..api.inventory.models import ApimodelsPaging
from ..api.inventory.models import ApimodelsPurchaseValidationItemReq
from ..api.inventory.models import ApimodelsPurchaseValidationReq
from ..api.inventory.models import ApimodelsRemoveInventoryItemReq
from ..api.inventory.models import ApimodelsRemoveItem
from ..api.inventory.models import ApimodelsSaveItemReq
from ..api.inventory.models import ApimodelsSaveItemToInventoryReq
from ..api.inventory.models import ApimodelsTradeItem
from ..api.inventory.models import ApimodelsTradeItemResp
from ..api.inventory.models import ApimodelsUpdateIntegrationConfigurationReq
from ..api.inventory.models import ApimodelsUpdateInventoryReq
from ..api.inventory.models import ApimodelsUpdateItem
from ..api.inventory.models import ApimodelsUpdateItemReq
from ..api.inventory.models import ApimodelsUpdateItemResp
from ..api.inventory.models import ApimodelsUpdateStatusIntegrationConfigurationReq


def create_apimodels_admin_update_item_req_example() -> ApimodelsAdminUpdateItemReq:
    instance = ApimodelsAdminUpdateItemReq()
    instance.custom_attributes = {randomize(): randomize()}
    instance.server_custom_attributes = {randomize(): randomize()}
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    return instance


def create_apimodels_chaining_operation_req_example() -> ApimodelsChainingOperationReq:
    instance = ApimodelsChainingOperationReq()
    instance.message = randomize()
    instance.operations = [create_apimodels_operation_example()]
    instance.request_id = randomize()
    return instance


def create_apimodels_chaining_operation_resp_example() -> (
    ApimodelsChainingOperationResp
):
    instance = ApimodelsChainingOperationResp()
    instance.message = randomize()
    instance.error_details = create_apimodels_error_response_example()
    instance.replayed = randomize("bool")
    instance.request_id = randomize()
    return instance


def create_apimodels_consume_item_example() -> ApimodelsConsumeItem:
    instance = ApimodelsConsumeItem()
    instance.inventory_id = randomize()
    instance.qty = randomize("int", min_val=1, max_val=1000)
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    return instance


def create_apimodels_consume_item_req_example() -> ApimodelsConsumeItemReq:
    instance = ApimodelsConsumeItemReq()
    instance.qty = randomize("int", min_val=1, max_val=1000)
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    return instance


def create_apimodels_create_integration_configuration_req_example() -> (
    ApimodelsCreateIntegrationConfigurationReq
):
    instance = ApimodelsCreateIntegrationConfigurationReq()
    instance.service_name = randomize()
    instance.target_inventory_code = randomize()
    instance.map_item_type = [randomize()]
    return instance


def create_apimodels_create_inventory_configuration_req_example() -> (
    ApimodelsCreateInventoryConfigurationReq
):
    instance = ApimodelsCreateInventoryConfigurationReq()
    instance.code = randomize()
    instance.initial_max_slots = randomize("int", min_val=1, max_val=1000)
    instance.max_instances_per_user = randomize("int", min_val=1, max_val=1000)
    instance.max_upgrade_slots = randomize("int", min_val=1, max_val=1000)
    instance.description = randomize()
    instance.name = randomize()
    return instance


def create_apimodels_create_inventory_req_example() -> ApimodelsCreateInventoryReq:
    instance = ApimodelsCreateInventoryReq()
    instance.inventory_configuration_code = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_apimodels_create_item_example() -> ApimodelsCreateItem:
    instance = ApimodelsCreateItem()
    instance.custom_attributes = {randomize(): randomize()}
    instance.qty = randomize("int", min_val=1, max_val=1000)
    instance.server_custom_attributes = {randomize(): randomize()}
    instance.slot_id = randomize()
    instance.slot_used = randomize("int", min_val=1, max_val=1000)
    instance.source_item_id = randomize()
    instance.tags = [randomize()]
    instance.to_specific_inventory = randomize("bool")
    instance.type_ = randomize()
    instance.inventory_configuration_code = randomize()
    instance.inventory_id = randomize()
    return instance


def create_apimodels_create_item_type_req_example() -> ApimodelsCreateItemTypeReq:
    instance = ApimodelsCreateItemTypeReq()
    instance.name = randomize()
    return instance


def create_apimodels_create_item_type_resp_example() -> ApimodelsCreateItemTypeResp:
    instance = ApimodelsCreateItemTypeResp()
    instance.created_at = randomize("date")
    instance.name = randomize()
    instance.namespace = randomize("slug")
    return instance


def create_apimodels_create_tag_req_example() -> ApimodelsCreateTagReq:
    instance = ApimodelsCreateTagReq()
    instance.name = randomize()
    instance.owner = randomize()
    return instance


def create_apimodels_create_tag_resp_example() -> ApimodelsCreateTagResp:
    instance = ApimodelsCreateTagResp()
    instance.created_at = randomize("date")
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.owner = randomize()
    return instance


def create_apimodels_delete_inventory_req_example() -> ApimodelsDeleteInventoryReq:
    instance = ApimodelsDeleteInventoryReq()
    instance.message = randomize()
    return instance


def create_apimodels_error_response_example() -> ApimodelsErrorResponse:
    instance = ApimodelsErrorResponse()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance


def create_apimodels_integration_configuration_resp_example() -> (
    ApimodelsIntegrationConfigurationResp
):
    instance = ApimodelsIntegrationConfigurationResp()
    instance.created_at = randomize("date")
    instance.id_ = randomize()
    instance.item_types = [randomize()]
    instance.namespace = randomize("slug")
    instance.service_name = randomize()
    instance.status = randomize()
    instance.target_inventory_code = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_apimodels_inventory_config_example() -> ApimodelsInventoryConfig:
    instance = ApimodelsInventoryConfig()
    instance.slot_used = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_inventory_configuration_req_example() -> (
    ApimodelsInventoryConfigurationReq
):
    instance = ApimodelsInventoryConfigurationReq()
    instance.code = randomize()
    instance.initial_max_slots = randomize("int", min_val=1, max_val=1000)
    instance.max_instances_per_user = randomize("int", min_val=1, max_val=1000)
    instance.max_upgrade_slots = randomize("int", min_val=1, max_val=1000)
    instance.description = randomize()
    instance.name = randomize()
    return instance


def create_apimodels_inventory_configuration_resp_example() -> (
    ApimodelsInventoryConfigurationResp
):
    instance = ApimodelsInventoryConfigurationResp()
    instance.code = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.id_ = randomize()
    instance.initial_max_slots = randomize("int", min_val=1, max_val=1000)
    instance.max_instances_per_user = randomize("int", min_val=1, max_val=1000)
    instance.max_upgrade_slots = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.status = randomize()
    instance.updated_at = randomize("date")
    return instance


def create_apimodels_inventory_resp_example() -> ApimodelsInventoryResp:
    instance = ApimodelsInventoryResp()
    instance.created_at = randomize("date")
    instance.id_ = randomize()
    instance.inventory_configuration_code = randomize()
    instance.inventory_configuration_id = randomize()
    instance.max_slots = randomize("int", min_val=1, max_val=1000)
    instance.max_upgrade_slots = randomize("int", min_val=1, max_val=1000)
    instance.namespace = randomize("slug")
    instance.updated_at = randomize("date")
    instance.used_count_slots = randomize("int", min_val=1, max_val=1000)
    instance.user_id = randomize("uid")
    return instance


def create_apimodels_item_resp_example() -> ApimodelsItemResp:
    instance = ApimodelsItemResp()
    instance.created_at = randomize("date")
    instance.custom_attributes = {randomize(): randomize()}
    instance.id_ = randomize()
    instance.inventory_id = randomize()
    instance.namespace = randomize("slug")
    instance.qty = randomize("int", min_val=1, max_val=1000)
    instance.server_custom_attributes = {randomize(): randomize()}
    instance.slot_id = randomize()
    instance.slot_used = randomize("int", min_val=1, max_val=1000)
    instance.source = randomize()
    instance.source_item_id = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    instance.updated_at = randomize("date")
    instance.user_id = randomize("uid")
    instance.platform_available = randomize("bool")
    return instance


def create_apimodels_list_integration_configurations_resp_example() -> (
    ApimodelsListIntegrationConfigurationsResp
):
    instance = ApimodelsListIntegrationConfigurationsResp()
    instance.data = [create_apimodels_integration_configuration_resp_example()]
    instance.paging = create_apimodels_paging_example()
    return instance


def create_apimodels_list_inventory_configurations_resp_example() -> (
    ApimodelsListInventoryConfigurationsResp
):
    instance = ApimodelsListInventoryConfigurationsResp()
    instance.data = [create_apimodels_inventory_configuration_resp_example()]
    instance.paging = create_apimodels_paging_example()
    return instance


def create_apimodels_list_inventory_resp_example() -> ApimodelsListInventoryResp:
    instance = ApimodelsListInventoryResp()
    instance.data = [create_apimodels_inventory_resp_example()]
    instance.paging = create_apimodels_paging_example()
    return instance


def create_apimodels_list_item_resp_example() -> ApimodelsListItemResp:
    instance = ApimodelsListItemResp()
    instance.data = [create_apimodels_item_resp_example()]
    instance.paging = create_apimodels_paging_example()
    return instance


def create_apimodels_list_item_types_resp_example() -> ApimodelsListItemTypesResp:
    instance = ApimodelsListItemTypesResp()
    instance.data = [create_apimodels_create_item_type_resp_example()]
    instance.paging = create_apimodels_paging_example()
    return instance


def create_apimodels_list_tags_resp_example() -> ApimodelsListTagsResp:
    instance = ApimodelsListTagsResp()
    instance.data = [create_apimodels_create_tag_resp_example()]
    instance.paging = create_apimodels_paging_example()
    return instance


def create_apimodels_move_items_req_example() -> ApimodelsMoveItemsReq:
    instance = ApimodelsMoveItemsReq()
    instance.items = [create_apimodels_trade_item_example()]
    instance.src_inventory_id = randomize()
    return instance


def create_apimodels_move_items_resp_example() -> ApimodelsMoveItemsResp:
    instance = ApimodelsMoveItemsResp()
    instance.created_at = randomize("date")
    instance.dst_inventory_id = randomize()
    instance.items = [create_apimodels_trade_item_resp_example()]
    instance.namespace = randomize("slug")
    instance.src_inventory_id = randomize()
    return instance


def create_apimodels_operation_example() -> ApimodelsOperation:
    instance = ApimodelsOperation()
    instance.consume_items = [create_apimodels_consume_item_example()]
    instance.create_items = [create_apimodels_create_item_example()]
    instance.remove_items = [create_apimodels_remove_item_example()]
    instance.target_user_id = randomize()
    instance.update_items = [create_apimodels_update_item_example()]
    return instance


def create_apimodels_paging_example() -> ApimodelsPaging:
    instance = ApimodelsPaging()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_apimodels_purchase_validation_item_req_example() -> (
    ApimodelsPurchaseValidationItemReq
):
    instance = ApimodelsPurchaseValidationItemReq()
    instance.bundled_qty = randomize("int", min_val=1, max_val=1000)
    instance.entitlement_type = randomize()
    instance.inventory_config = create_apimodels_inventory_config_example()
    instance.item_id = randomize()
    instance.item_type = randomize()
    instance.sku = randomize("slug")
    instance.stackable = randomize("bool")
    instance.use_count = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_purchase_validation_req_example() -> (
    ApimodelsPurchaseValidationReq
):
    instance = ApimodelsPurchaseValidationReq()
    instance.item_id = randomize()
    instance.item_type = randomize()
    instance.quantity = randomize("int", min_val=1, max_val=1000)
    instance.sku = randomize("slug")
    instance.stackable = randomize("bool")
    instance.entitlement_type = randomize()
    instance.inventory_config = create_apimodels_inventory_config_example()
    instance.items = [create_apimodels_purchase_validation_item_req_example()]
    instance.use_count = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_remove_inventory_item_req_example() -> (
    ApimodelsRemoveInventoryItemReq
):
    instance = ApimodelsRemoveInventoryItemReq()
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    return instance


def create_apimodels_remove_item_example() -> ApimodelsRemoveItem:
    instance = ApimodelsRemoveItem()
    instance.inventory_id = randomize()
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    return instance


def create_apimodels_save_item_req_example() -> ApimodelsSaveItemReq:
    instance = ApimodelsSaveItemReq()
    instance.custom_attributes = {randomize(): randomize()}
    instance.inventory_configuration_code = randomize()
    instance.qty = randomize("int", min_val=1, max_val=1000)
    instance.server_custom_attributes = {randomize(): randomize()}
    instance.slot_id = randomize()
    instance.slot_used = randomize("int", min_val=1, max_val=1000)
    instance.source = randomize()
    instance.source_item_id = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    return instance


def create_apimodels_save_item_to_inventory_req_example() -> (
    ApimodelsSaveItemToInventoryReq
):
    instance = ApimodelsSaveItemToInventoryReq()
    instance.custom_attributes = {randomize(): randomize()}
    instance.qty = randomize("int", min_val=1, max_val=1000)
    instance.server_custom_attributes = {randomize(): randomize()}
    instance.slot_id = randomize()
    instance.slot_used = randomize("int", min_val=1, max_val=1000)
    instance.source = randomize()
    instance.source_item_id = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    return instance


def create_apimodels_trade_item_example() -> ApimodelsTradeItem:
    instance = ApimodelsTradeItem()
    instance.qty = randomize("int", min_val=1, max_val=1000)
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    return instance


def create_apimodels_trade_item_resp_example() -> ApimodelsTradeItemResp:
    instance = ApimodelsTradeItemResp()
    instance.qty = randomize("int", min_val=1, max_val=1000)
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    return instance


def create_apimodels_update_integration_configuration_req_example() -> (
    ApimodelsUpdateIntegrationConfigurationReq
):
    instance = ApimodelsUpdateIntegrationConfigurationReq()
    instance.service_name = randomize()
    instance.target_inventory_code = randomize()
    instance.map_item_type = [randomize()]
    return instance


def create_apimodels_update_inventory_req_example() -> ApimodelsUpdateInventoryReq:
    instance = ApimodelsUpdateInventoryReq()
    instance.inc_max_slots = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodels_update_item_example() -> ApimodelsUpdateItem:
    instance = ApimodelsUpdateItem()
    instance.custom_attributes = {randomize(): randomize()}
    instance.inventory_id = randomize()
    instance.server_custom_attributes = {randomize(): randomize()}
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    return instance


def create_apimodels_update_item_req_example() -> ApimodelsUpdateItemReq:
    instance = ApimodelsUpdateItemReq()
    instance.custom_attributes = {randomize(): randomize()}
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    instance.tags = [randomize()]
    return instance


def create_apimodels_update_item_resp_example() -> ApimodelsUpdateItemResp:
    instance = ApimodelsUpdateItemResp()
    instance.slot_id = randomize()
    instance.source_item_id = randomize()
    instance.success = randomize("bool")
    instance.error_details = create_apimodels_error_response_example()
    return instance


def create_apimodels_update_status_integration_configuration_req_example() -> (
    ApimodelsUpdateStatusIntegrationConfigurationReq
):
    instance = ApimodelsUpdateStatusIntegrationConfigurationReq()
    instance.status = randomize()
    return instance
